==> SeasObjects_for_Python-1.0.1.tar.gz: SeasObjects_for_Python-1.0.1/SeasObjects/common/PROPERTY.py <==
from NS import NS

class PROPERTY(object):

	# geo
	GEO_LAT = NS.GEO + "lat"
	GEO_LONG = NS.GEO + "long"
	GEO_ALT = NS.GEO + "alt"

	# owl
	OWL_SAMEAS = NS.OWL + "sameAs"
		
	# rdf
	RDF_TYPE = NS.RDF + "type"
	RDF_VALUE = NS.RDF + "value"
	RDF_FIRST = NS.RDF + "nil"
	RDF_REST = NS.RDF + "rest"
	RDF_NIL = NS.RDF + "nil"
	
	# rdfs
	RDFS_LABEL = NS.RDFS + "label"

	# seas
	SEAS_ACTIVITY = NS.SEAS + "activity"
	SEAS_ACTOR = NS.SEAS + "actor"
	SEAS_ALLENRELATION = NS.SEAS + "allenRelation"
	SEAS_AND = NS.SEAS + "and"
	SEAS_CAPACITY = NS.SEAS + "capacity"
	SEAS_CATEGORY = NS.SEAS + "category"
	SEAS_COMPLETED = NS.SEAS + "completed"
	SEAS_CONSTRAINT = NS.SEAS + "constraint"
	SEAS_CONTAINS = NS.SEAS + "contains"
	SEAS_CONTENTTYPE = NS.SEAS + "contentType"
	SEAS_CONTROLPOINTOF = NS.SEAS + "controlPointOf"
	SEAS_DATASOURCE = NS.SEAS + "dataSource"
	SEAS_DURATION = NS.SEAS + "duration"
	SEAS_DURING = NS.SEAS + "during"
	SEAS_END = NS.SEAS + "end"
	SEAS_ENTITY = NS.SEAS + "entity"
	SEAS_ENTRY = NS.SEAS + "entry"
	SEAS_ERROR = NS.SEAS + "error"
	SEAS_ERRORMESSAGE = NS.SEAS + "errorMessage"
	SEAS_ERRORCODE = NS.SEAS + "errorCode"
	SEAS_FEATUREOFINTEREST = NS.SEAS + "featureOfInterest"
	SEAS_GENERATEDAT = NS.SEAS + "generatedAt"
	SEAS_GENERATEDBY = NS.SEAS + "generatedBy"
	SEAS_GENERATIONMETHOD = NS.SEAS + "generationMethod"
	SEAS_HASAVAILABILITY = NS.SEAS + "hasAvailability"
	SEAS_HASCAPABILITY = NS.SEAS + "hasCapability"
	SEAS_HASCOMFORTPROFILE = NS.SEAS + "hasComfortProfile"
	SEAS_HASCONDITION = NS.SEAS + "hasCondition"
	SEAS_HASDATAAVAILABILITY = NS.SEAS + "hasDataAvailability"
	SEAS_HASDATARESOURCE = NS.SEAS + "hasDataResource"
	SEAS_HASDIRECTPART = NS.SEAS + "hasDirectPart"
	SEAS_HASEVALUATION = NS.SEAS + "hasEvaluation"
	SEAS_HASINPUT = NS.SEAS + "hasInput"
	SEAS_HASOPENING = NS.SEAS + "hasOpening"
	SEAS_HASOUTPUT = NS.SEAS + "hasOutput"
	SEAS_HASPART = NS.SEAS + "hasPart"
	SEAS_HASPROFILE = NS.SEAS + "hasProfile"
	SEAS_HASREFINPUT = NS.SEAS + "hasRefInput"
	SEAS_HASROLE = NS.SEAS + "hasRole"
	SEAS_HOST = NS.SEAS + "host"
	SEAS_INSTANT = NS.SEAS + "instant"
	SEAS_INTERFACE = NS.SEAS + "interface"
	SEAS_ISADJACENTTOSPACE = NS.SEAS + "isAdjacentToSpace"
	SEAS_ISCONTROLLEDBY = NS.SEAS + "isControlledBy"
	SEAS_ISMANAGEDBY = NS.SEAS + "isManagedBy"
	SEAS_ISOWNEDBY = NS.SEAS + "isOwnedBy"
	SEAS_KEY = NS.SEAS + "key"
	SEAS_LIST = NS.SEAS + "list"
	SEAS_LOCATION = NS.SEAS + "location"
	SEAS_MAP = NS.SEAS + "map"
	SEAS_MINLOCATION = NS.SEAS + "minLocation"
	SEAS_MINRADIUS = NS.SEAS + "minRadius"
	SEAS_MAXIMUM = NS.SEAS + "maximum"
	SEAS_MAXLOCATION = NS.SEAS + "maxLocation"
	SEAS_MAXRADIUS = NS.SEAS + "maxRadius"
	SEAS_MEAN = NS.SEAS + "mean"
	SEAS_MEDIAN = NS.SEAS + "median"
	SEAS_MESUREMENTPOINTOF = NS.SEAS + "mesurementPointOf"
	SEAS_MESSAGEID = NS.SEAS + "messageId"
	SEAS_METHOD = NS.SEAS + "method"
	SEAS_MINIMUM = NS.SEAS + "minimum"
	SEAS_OFFERSSERVICE = NS.SEAS + "offersService"
	SEAS_OR = NS.SEAS + "or"
	SEAS_OWNS = NS.SEAS + "owns"
	SEAS_PATH = NS.SEAS + "path"
	SEAS_PERCENTAGE = NS.SEAS + "percentage"
	SEAS_POLYGON = NS.SEAS + "polygon"
	SEAS_PORT = NS.SEAS + "port"
	SEAS_PROCESSID = NS.SEAS + "processId"
	SEAS_PROPERTY = NS.SEAS + "property"
	SEAS_PROVENANCE = NS.SEAS + "provenance"
	SEAS_QUANTITY = NS.SEAS + "quantity"
	SEAS_QUARTILE0 = NS.SEAS + "quartile0"
	SEAS_QUARTILE1 = NS.SEAS + "quartile1"
	SEAS_QUARTILE2 = NS.SEAS + "quartile2"
	SEAS_QUARTILE3 = NS.SEAS + "quartile3"
	SEAS_QUARTILE4 = NS.SEAS + "quartile4"
	SEAS_RANGE = NS.SEAS + "range"
	SEAS_RANK = NS.SEAS + "rank"
	SEAS_REALIZEDBY = NS.SEAS + "realizedBy"
	SEAS_REGEX = NS.SEAS + "regex"
	SEAS_REGISTERKEY = NS.SEAS + "registerKey"
	SEAS_SCHEME = NS.SEAS + "scheme"
	SEAS_SERVICE = NS.SEAS + "service"
	SEAS_SIGNIFICANTVALUECHANGE = NS.SEAS + "significantValueChange"
	SEAS_SPREAD = NS.SEAS + "spread"
	SEAS_START = NS.SEAS + "start"
	SEAS_STATUS = NS.SEAS + "status"
	SEAS_SUBCONTROL = NS.SEAS + "subControl"
	SEAS_SUBMEASUREMENT = NS.SEAS + "subMeasurement"
	SEAS_SYSTEMOFINTEREST = NS.SEAS + "systemOfInterest"
	SEAS_TEMPORALCONTEXT = NS.SEAS + "temporalContext"
	SEAS_TIME = NS.SEAS + "time"
	SEAS_TIMESERIES = NS.SEAS + "timeSeries"
	SEAS_TIMESTEP = NS.SEAS + "timeStep"
	SEAS_TOTAL = NS.SEAS + "total"
	SEAS_UNIT = NS.SEAS + "unit"
	SEAS_VALUE = NS.SEAS + "value"
	SEAS_VALUEOBJECT = NS.SEAS + "valueObject"
	SEAS_WEATHERDESCRIPTION = NS.SEAS + "weatherDescription"
	SEAS_ZONE = NS.SEAS + "zone"

	# vcard
	VCARD_COUNTRY_NAME = NS.VCARD + "country-name"
	VCARD_HASURL = NS.VCARD + "hasURL"
	VCARD_LOCALITY = NS.VCARD + "locality"
	VCARD_POSTAL_CODE = NS.VCARD + "postal-code"
	VCARD_STREET_ADDRESS = NS.VCARD + "street-address"

	SEAS_SPEED = NS.SEAS + "speed"
	SEAS_ANGULAR_SPEED_X = NS.SEAS + "angularSpeedX"
	SEAS_ANGULAR_SPEED_Y = NS.SEAS + "angularSpeedY"
	SEAS_ANGULAR_SPEED_Z = NS.SEAS + "angularSpeedZ"
	SEAS_LINEAR_SPEED_X = NS.SEAS + "linearSpeedX"
	SEAS_LINEAR_SPEED_Y = NS.SEAS + "linearSpeedY"
	SEAS_LINEAR_SPEED_Z = NS.SEAS + "linearSpeedZ"
	SEAS_GROUND_SPEED = NS.SEAS + "groundSpeed"
	
	SEAS_ORIENTATION = NS.SEAS + "orientation"
	SEAS_DIRECTION = NS.SEAS + "direction"
	SEAS_WEIGHT = NS.SEAS + "weight"
	SEAS_SIZE = NS.SEAS + "size"
	SEAS_WIDTH = NS.SEAS + "width"
	SEAS_LENGTH = NS.SEAS + "length"
	SEAS_HEIGHT = NS.SEAS + "height"
	SEAS_DEPTH = NS.SEAS + "depth"
	
	SEAS_YAW = NS.SEAS + "yaw"
	SEAS_PITCH = NS.SEAS + "pitch"
	SEAS_ROLL = NS.SEAS + "roll"
	
	SEAS_COORDINATES = NS.SEAS + "coordinates"
	SEAS_BEARING = NS.SEAS + "bearing"
	SEAS_HEADING = NS.SEAS + "heading"
	SEAS_TRACKING = NS.SEAS + "tracking"
	SEAS_COURSE = NS.SEAS + "course"
	SEAS_ROUTE = NS.SEAS + "route"
	
	SEAS_PARAMETER = NS.SEAS + "parameter"
	SEAS_PARAMETER_KEY = NS.SEAS + "key"

==> SeasObjects_for_Python-1.0.4.tar.gz: SeasObjects_for_Python-1.0.4/SeasObjects/common/PROPERTY.py <==
from NS import NS

class PROPERTY(object):

	# geo
	GEO_LAT = NS.GEO + "lat"
	GEO_LONG = NS.GEO + "long"
	GEO_ALT = NS.GEO + "alt"

	# owl
	OWL_SAMEAS = NS.OWL + "sameAs"
		
	# rdf
	RDF_TYPE = NS.RDF + "type"
	RDF_VALUE = NS.RDF + "value"
	RDF_FIRST = NS.RDF + "nil"
	RDF_REST = NS.RDF + "rest"
	RDF_NIL = NS.RDF + "nil"
	
	# rdfs
	RDFS_COMMENT = NS.RDFS + "comment"
	RDFS_LABEL = NS.RDFS + "label"
	
	# dc
	DC_CREATOR = NS.DC + "creator"

	# vcard
	VCARD_COUNTRY_NAME = NS.VCARD + "country-name";
	VCARD_HASURL = NS.VCARD + "hasURL";
	VCARD_LOCALITY = NS.VCARD + "locality";
	VCARD_POSTAL_CODE = NS.VCARD + "postal-code";
	VCARD_STREET_ADDRESS = NS.VCARD + "street-address";
	VCARD_HASADDRESS = NS.VCARD + "hasAddress";
	VCARD_HASLOGO = NS.VCARD + "hasLogo";
	VCARD_HASPHOTO = NS.VCARD + "hasPhoto";
	VCARD_HASSOUND = NS.VCARD + "hasSound";
		
	# seas
	SEAS_ACTIVITY = NS.SEAS + "activity"
	SEAS_ACTOR = NS.SEAS + "actor"
	SEAS_ALLENRELATION = NS.SEAS + "allenRelation"
	SEAS_AND = NS.SEAS + "and"
	SEAS_AVERAGESPEED = NS.SEAS + "averageSpeed"
	SEAS_CAPACITY = NS.SEAS + "capacity"
	SEAS_CATEGORY = NS.SEAS + "category"
	SEAS_COMPLETED = NS.SEAS + "completed"
	SEAS_CONSTRAINT = NS.SEAS + "constraint"
	SEAS_CONTAINS = NS.SEAS + "contains"
	SEAS_CONTENTTYPE = NS.SEAS + "contentType"
	SEAS_CONTROLPOINTOF = NS.SEAS + "controlPointOf"
	SEAS_DATASOURCE = NS.SEAS + "dataSource"
	SEAS_DURATION = NS.SEAS + "duration"
	SEAS_DURING = NS.SEAS + "during"
	SEAS_END = NS.SEAS + "end"
	SEAS_ENERGYCONSUMPTION = NS.SEAS + "energyConsumption"
	SEAS_ENTITY = NS.SEAS + "entity"
	SEAS_ENTRY = NS.SEAS + "entry"
	SEAS_ERROR = NS.SEAS + "error"
	SEAS_ERRORMESSAGE = NS.SEAS + "errorMessage"
	SEAS_ERRORCODE = NS.SEAS + "errorCode"
	SEAS_FEATUREOFINTEREST = NS.SEAS + "featureOfInterest"
	SEAS_GENERATEDAT = NS.SEAS + "generatedAt"
	SEAS_GENERATEDBY = NS.SEAS + "generatedBy"
	SEAS_GENERATIONMETHOD = NS.SEAS + "generationMethod"
	SEAS_HASAVAILABILITY = NS.SEAS + "hasAvailability"
	SEAS_HASCAPABILITY = NS.SEAS + "hasCapability"
	SEAS_HASCOMFORTPROFILE = NS.SEAS + "hasComfortProfile"
	SEAS_HASCONDITION = NS.SEAS + "hasCondition"
	SEAS_HASDATAAVAILABILITY = NS.SEAS + "hasDataAvailability"
	SEAS_HASDATARESOURCE = NS.SEAS + "hasDataResource"
	SEAS_HASDIRECTPART = NS.SEAS + "hasDirectPart"
	SEAS_HASEVALUATION = NS.SEAS + "hasEvaluation"
	SEAS_HASINPUT = NS.SEAS + "hasInput"
	SEAS_HASOPENING = NS.SEAS + "hasOpening"
	SEAS_HASOUTPUT = NS.SEAS + "hasOutput"
	SEAS_HASPART = NS.SEAS + "hasPart"
	SEAS_HASPROFILE = NS.SEAS + "hasProfile"
	SEAS_HASREFINPUT = NS.SEAS + "hasRefInput"
	SEAS_HASROLE = NS.SEAS + "hasRole"
	SEAS_HOST = NS.SEAS + "host"
	SEAS_INSTANT = NS.SEAS + "instant"
	SEAS_INTERFACE = NS.SEAS + "interface"
	SEAS_ISADJACENTTOSPACE = NS.SEAS + "isAdjacentToSpace"
	SEAS_ISCONTROLLEDBY = NS.SEAS + "isControlledBy"
	SEAS_ISMANAGEDBY = NS.SEAS + "isManagedBy"
	SEAS_ISOWNEDBY = NS.SEAS + "isOwnedBy"
	SEAS_KEY = NS.SEAS + "key"
	SEAS_LIST = NS.SEAS + "list"
	SEAS_LOCATION = NS.SEAS + "location"
	SEAS_MAP = NS.SEAS + "map"
	SEAS_MINLOCATION = NS.SEAS + "minLocation"
	SEAS_MINRADIUS = NS.SEAS + "minRadius"
	SEAS_MAXIMUM = NS.SEAS + "maximum"
	SEAS_MAXLOCATION = NS.SEAS + "maxLocation"
	SEAS_MAXRADIUS = NS.SEAS + "maxRadius"
	SEAS_MEAN = NS.SEAS + "mean"
	SEAS_MEDIAN = NS.SEAS + "median"
	SEAS_MESUREMENTPOINTOF = NS.SEAS + "mesurementPointOf"
	SEAS_MESSAGEID = NS.SEAS + "messageId"
	SEAS_METHOD = NS.SEAS + "method"
	SEAS_MINIMUM = NS.SEAS + "minimum"
	SEAS_OFFERSSERVICE = NS.SEAS + "offersService"
	SEAS_OR = NS.SEAS + "or"
	SEAS_OWNS = NS.SEAS + "owns"
	SEAS_OWNER = NS.SEAS + "owner"
	SEAS_PATH = NS.SEAS + "path"
	SEAS_PERCENTAGE = NS.SEAS + "percentage"
	SEAS_POLYGON = NS.SEAS + "polygon"
	SEAS_PORT = NS.SEAS + "port"
	SEAS_PROCESSID = NS.SEAS + "processId"
	SEAS_PROPERTY = NS.SEAS + "property"
	SEAS_PROVENANCE = NS.SEAS + "provenance"
	SEAS_QUANTITY = NS.SEAS + "quantity"
	SEAS_QUARTILE0 = NS.SEAS + "quartile0"
	SEAS_QUARTILE1 = NS.SEAS + "quartile1"
	SEAS_QUARTILE2 = NS.SEAS + "quartile2"
	SEAS_QUARTILE3 = NS.SEAS + "quartile3"
	SEAS_QUARTILE4 = NS.SEAS + "quartile4"
	SEAS_RANGE = NS.SEAS + "range"
	SEAS_RANK = NS.SEAS + "rank"
	SEAS_REALIZEDBY = NS.SEAS + "realizedBy"
	SEAS_REGEX = NS.SEAS + "regex"
	SEAS_REGISTERKEY = NS.SEAS + "registerKey"
	SEAS_SCHEME = NS.SEAS + "scheme"
	SEAS_SERVICE = NS.SEAS + "service"
	SEAS_SIGNIFICANTVALUECHANGE = NS.SEAS + "significantValueChange"
	SEAS_SPREAD = NS.SEAS + "spread"
	SEAS_START = NS.SEAS + "start"
	SEAS_STATUS = NS.SEAS + "status"
	SEAS_SUBCONTROL = NS.SEAS + "subControl"
	SEAS_SUBMEASUREMENT = NS.SEAS + "subMeasurement"
	SEAS_SYSTEMOFINTEREST = NS.SEAS + "systemOfInterest"
	SEAS_TEMPORALCONTEXT = NS.SEAS + "temporalContext"
	SEAS_TIME = NS.SEAS + "time"
	SEAS_TIMESERIES = NS.SEAS + "timeSeries"
	SEAS_TIMESTEP = NS.SEAS + "timeStep"
	SEAS_TOTAL = NS.SEAS + "total"
	SEAS_UNIT = NS.SEAS + "unit"
	SEAS_VALUE = NS.SEAS + "value"
	SEAS_VALUEOBJECT = NS.SEAS + "valueObject"
	SEAS_WEATHERDESCRIPTION = NS.SEAS + "weatherDescription"
	SEAS_ZONE = NS.SEAS + "zone"
	SEAS_ZONENUMBER = NS.SEAS + "zoneNumber"

	# vcard
	VCARD_COUNTRY_NAME = NS.VCARD + "country-name"
	VCARD_HASURL = NS.VCARD + "hasURL"
	VCARD_LOCALITY = NS.VCARD + "locality"
	VCARD_POSTAL_CODE = NS.VCARD + "postal-code"
	VCARD_STREET_ADDRESS = NS.VCARD + "street-address"

	SEAS_SPEED = NS.SEAS + "speed"
	SEAS_ANGULAR_SPEED_X = NS.SEAS + "angularSpeedX"
	SEAS_ANGULAR_SPEED_Y = NS.SEAS + "angularSpeedY"
	SEAS_ANGULAR_SPEED_Z = NS.SEAS + "angularSpeedZ"
	SEAS_LINEAR_SPEED_X = NS.SEAS + "linearSpeedX"
	SEAS_LINEAR_SPEED_Y = NS.SEAS + "linearSpeedY"
	SEAS_LINEAR_SPEED_Z = NS.SEAS + "linearSpeedZ"
	SEAS_GROUND_SPEED = NS.SEAS + "groundSpeed"
	
	SEAS_ORIENTATION = NS.SEAS + "orientation"
	SEAS_DIRECTION = NS.SEAS + "direction"
	SEAS_WEIGHT = NS.SEAS + "weight"
	SEAS_SIZE = NS.SEAS + "size"
	SEAS_WIDTH = NS.SEAS + "width"
	SEAS_LENGTH = NS.SEAS + "length"
	SEAS_HEIGHT = NS.SEAS + "height"
	SEAS_DEPTH = NS.SEAS + "depth"
	
	SEAS_YAW = NS.SEAS + "yaw"
	SEAS_PITCH = NS.SEAS + "pitch"
	SEAS_ROLL = NS.SEAS + "roll"
	
	SEAS_COORDINATES = NS.SEAS + "coordinates"
	SEAS_BEARING = NS.SEAS + "bearing"
	SEAS_HEADING = NS.SEAS + "heading"
	SEAS_TRACKING = NS.SEAS + "tracking"
	SEAS_COURSE = NS.SEAS + "course"
	SEAS_ROUTE = NS.SEAS + "route"
	
	SEAS_PARAMETER = NS.SEAS + "parameter"
	SEAS_PARAMETER_KEY = NS.SEAS + "key"
